# qcal

qcal is software for quantum calibration, characterization, and benchmarking. 

# Installation

Install from PyPI:

```bash
pip install quantum-calibration
```

# Getting started

Here's an example of creating a Bell state preparation circuit in qcal:

```python
import qcal as qc

circuit = qc.Circuit([
  qc.Cycle({qc.H(0)}),
  qc.Cycle({qc.CNOT((0, 1))})
])
circuit.measure()
circuit.draw()
```

# License & Copyright

qcal is licensed under a [BSD license](https://github.com/akelhashim/qcal/blob/main/LICENSE).

***Copyright Notice***

qcal Copyright (c) 2025, The Regents of the University of California,
through Lawrence Berkeley National Laboratory (subject to receipt of
any required approvals from the U.S. Dept. of Energy). All rights reserved.

If you have questions about your rights to use or distribute this software,
please contact Berkeley Lab's Intellectual Property Office at
IPO@lbl.gov.

NOTICE. This Software was developed under funding from the U.S. Department
of Energy and the U.S. Government consequently retains certain rights.  As
such, the U.S. Government has been granted for itself and others acting on
its behalf a paid-up, nonexclusive, irrevocable, worldwide license in the
Software to reproduce, distribute copies to the public, prepare derivative 
works, and perform publicly and display publicly, and to permit others to do so.

# Citation
If using qcal for research, please [cite](https://www.osti.gov/doecode/biblio/169551):
```
@misc{doecode_169551,
title = {qcal v0.0.1},
author = {Hashim, Akel},
abstractNote = {qcal is a software package for calibration, characterization, and benchmarking of quantum gates. It was developed to operate full-stack superconducting quantum systems at the Advanced Quantum Testbed.},
doi = {10.11578/dc.20251106.3},
url = {https://doi.org/10.11578/dc.20251106.3},
howpublished = {[Computer Software] \url{https://doi.org/10.11578/dc.20251106.3}},
year = {2025},
month = {nov}
}
```
